@@ -11,7 +11,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.cdk
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.31.0", __name__, "aws-kms@0.31.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.32.0", __name__, "aws-kms@0.32.0.jsii.tgz")
 class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnAlias"):
     """A CloudFormation ``AWS::KMS::Alias``.
 
@@ -234,7 +234,7 @@ class EncryptionKeyAlias(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_ty
 
     You can also add an alias for a key by calling ``key.addAlias(alias)``.
     """
-    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, alias: str, key: "IEncryptionKey") -> None:
+    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, alias: str, key: "IKey") -> None:
         """
         Arguments:
             scope: -
@@ -268,7 +268,7 @@ class EncryptionKeyAliasProps(jsii.compat.TypedDict):
     alias/AWS. These aliases are reserved.
     """
 
-    key: "IEncryptionKey"
+    key: "IKey"
     """The ID of the key for which you are creating the alias.
 
     Specify the key's
@@ -276,63 +276,20 @@ class EncryptionKeyAliasProps(jsii.compat.TypedDict):
     specify another alias.
     """
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-kms.EncryptionKeyImportProps", jsii_struct_bases=[])
-class EncryptionKeyImportProps(jsii.compat.TypedDict):
-    keyArn: str
-    """The ARN of the external KMS key."""
-
-@jsii.data_type(jsii_type="@aws-cdk/aws-kms.EncryptionKeyProps", jsii_struct_bases=[])
-class EncryptionKeyProps(jsii.compat.TypedDict, total=False):
-    """Construction properties for a KMS Key object."""
-    description: str
-    """A description of the key.
-
-    Use a description that helps your users decide
-    whether the key is appropriate for a particular task.
-    """
-
-    enabled: bool
-    """Indicates whether the key is available for use.
-
-    Default:
-        Key is enabled
-    """
-
-    enableKeyRotation: bool
-    """Indicates whether AWS KMS rotates the key.
-
-    Default:
-        false
-    """
-
-    policy: aws_cdk.aws_iam.PolicyDocument
-    """Custom policy document to attach to the KMS key.
-
-    Default:
-        A policy document with permissions for the account root to
-        administer the key will be created.
-    """
-
-    retain: bool
-    """Whether the encryption key should be retained when it is removed from the Stack.
-
-    This is useful when one wants to
-    retain access to data that was encrypted with a key that is being retired.
-
-    Default:
-        true
-    """
-
-@jsii.interface(jsii_type="@aws-cdk/aws-kms.IEncryptionKey")
-class IEncryptionKey(aws_cdk.cdk.IConstruct, jsii.compat.Protocol):
+@jsii.interface(jsii_type="@aws-cdk/aws-kms.IKey")
+class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
     @staticmethod
     def __jsii_proxy_class__():
-        return _IEncryptionKeyProxy
+        return _IKeyProxy
 
     @property
     @jsii.member(jsii_name="keyArn")
     def key_arn(self) -> str:
-        """The ARN of the key."""
+        """The ARN of the key.
+
+        attribute:
+            true
+        """
         ...
 
     @jsii.member(jsii_name="addAlias")
@@ -354,15 +311,6 @@ class IEncryptionKey(aws_cdk.cdk.IConstruct, jsii.compat.Protocol):
         """
         ...
 
-    @jsii.member(jsii_name="export")
-    def export(self) -> "EncryptionKeyImportProps":
-        """Exports this key from the current stack.
-
-        Returns:
-            a key ref which can be used in a call to ``EncryptionKey.import(ref)``.
-        """
-        ...
-
     @jsii.member(jsii_name="grant")
     def grant(self, grantee: aws_cdk.aws_iam.IGrantable, *actions: str) -> aws_cdk.aws_iam.Grant:
         """Grant the indicated permissions on this key to the given principal.
@@ -401,12 +349,16 @@ class IEncryptionKey(aws_cdk.cdk.IConstruct, jsii.compat.Protocol):
         ...
 
 
-class _IEncryptionKeyProxy(jsii.proxy_for(aws_cdk.cdk.IConstruct)):
-    __jsii_type__ = "@aws-cdk/aws-kms.IEncryptionKey"
+class _IKeyProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
+    __jsii_type__ = "@aws-cdk/aws-kms.IKey"
     @property
     @jsii.member(jsii_name="keyArn")
     def key_arn(self) -> str:
-        """The ARN of the key."""
+        """The ARN of the key.
+
+        attribute:
+            true
+        """
         return jsii.get(self, "keyArn")
 
     @jsii.member(jsii_name="addAlias")
@@ -428,15 +380,6 @@ class _IEncryptionKeyProxy(jsii.proxy_for(aws_cdk.cdk.IConstruct)):
         """
         return jsii.invoke(self, "addToResourcePolicy", [statement, allow_no_op])
 
-    @jsii.member(jsii_name="export")
-    def export(self) -> "EncryptionKeyImportProps":
-        """Exports this key from the current stack.
-
-        Returns:
-            a key ref which can be used in a call to ``EncryptionKey.import(ref)``.
-        """
-        return jsii.invoke(self, "export", [])
-
     @jsii.member(jsii_name="grant")
     def grant(self, grantee: aws_cdk.aws_iam.IGrantable, *actions: str) -> aws_cdk.aws_iam.Grant:
         """Grant the indicated permissions on this key to the given principal.
@@ -475,8 +418,8 @@ class _IEncryptionKeyProxy(jsii.proxy_for(aws_cdk.cdk.IConstruct)):
         return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
 
 
-@jsii.implements(IEncryptionKey)
-class EncryptionKey(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.EncryptionKey"):
+@jsii.implements(IKey)
+class Key(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Key"):
     """Defines a KMS key."""
     def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, retain: typing.Optional[bool]=None) -> None:
         """
@@ -484,13 +427,13 @@ class EncryptionKey(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@
             scope: -
             id: -
             props: -
-            description: A description of the key. Use a description that helps your users decide whether the key is appropriate for a particular task.
-            enabled: Indicates whether the key is available for use. Default: Key is enabled
+            description: A description of the key. Use a description that helps your users decide whether the key is appropriate for a particular task. Default: - No description.
+            enabled: Indicates whether the key is available for use. Default: - Key is enabled.
             enableKeyRotation: Indicates whether AWS KMS rotates the key. Default: false
-            policy: Custom policy document to attach to the KMS key. Default: A policy document with permissions for the account root to administer the key will be created.
+            policy: Custom policy document to attach to the KMS key. Default: - A policy document with permissions for the account root to administer the key will be created.
             retain: Whether the encryption key should be retained when it is removed from the Stack. This is useful when one wants to retain access to data that was encrypted with a key that is being retired. Default: true
         """
-        props: EncryptionKeyProps = {}
+        props: KeyProps = {}
 
         if description is not None:
             props["description"] = description
@@ -507,33 +450,18 @@ class EncryptionKey(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@
         if retain is not None:
             props["retain"] = retain
 
-        jsii.create(EncryptionKey, self, [scope, id, props])
+        jsii.create(Key, self, [scope, id, props])
 
-    @jsii.member(jsii_name="import")
+    @jsii.member(jsii_name="fromKeyArn")
     @classmethod
-    def import_(cls, scope: aws_cdk.cdk.Construct, id: str, *, key_arn: str) -> "IEncryptionKey":
-        """Defines an imported encryption key.
-
-        ``ref`` can be obtained either via a call to ``key.export()`` or using
-        literals.
-
-        For example:
-
-        const keyAttr = key.export();
-        const keyRef1 = EncryptionKey.import(this, 'MyImportedKey1', keyAttr);
-        const keyRef2 = EncryptionKey.import(this, 'MyImportedKey2', {
-        keyArn: new KeyArn('arn:aws:kms:...')
-        });
-
-        Arguments:
-            scope: The parent construct.
-            id: The name of the construct.
-            props: The key reference.
-            keyArn: The ARN of the external KMS key.
+    def from_key_arn(cls, scope: aws_cdk.cdk.Construct, id: str, key_arn: str) -> "IKey":
         """
-        props: EncryptionKeyImportProps = {"keyArn": key_arn}
-
-        return jsii.sinvoke(cls, "import", [scope, id, props])
+        Arguments:
+            scope: -
+            id: -
+            keyArn: -
+        """
+        return jsii.sinvoke(cls, "fromKeyArn", [scope, id, key_arn])
 
     @jsii.member(jsii_name="addAlias")
     def add_alias(self, alias: str) -> "EncryptionKeyAlias":
@@ -554,15 +482,6 @@ class EncryptionKey(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@
         """
         return jsii.invoke(self, "addToResourcePolicy", [statement, allow_no_op])
 
-    @jsii.member(jsii_name="export")
-    def export(self) -> "EncryptionKeyImportProps":
-        """Exports this key from the current stack.
-
-        Returns:
-            a key ref which can be used in a call to ``EncryptionKey.import(ref)``.
-        """
-        return jsii.invoke(self, "export", [])
-
     @jsii.member(jsii_name="grant")
     def grant(self, grantee: aws_cdk.aws_iam.IGrantable, *actions: str) -> aws_cdk.aws_iam.Grant:
         """Grant the indicated permissions on this key to the given principal.
@@ -621,6 +540,51 @@ class EncryptionKey(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "policy")
 
 
+@jsii.data_type(jsii_type="@aws-cdk/aws-kms.KeyProps", jsii_struct_bases=[])
+class KeyProps(jsii.compat.TypedDict, total=False):
+    """Construction properties for a KMS Key object."""
+    description: str
+    """A description of the key.
+
+    Use a description that helps your users decide
+    whether the key is appropriate for a particular task.
+
+    Default:
+        - No description.
+    """
+
+    enabled: bool
+    """Indicates whether the key is available for use.
+
+    Default:
+        - Key is enabled.
+    """
+
+    enableKeyRotation: bool
+    """Indicates whether AWS KMS rotates the key.
+
+    Default:
+        false
+    """
+
+    policy: aws_cdk.aws_iam.PolicyDocument
+    """Custom policy document to attach to the KMS key.
+
+    Default:
+        - A policy document with permissions for the account root to
+          administer the key will be created.
+    """
+
+    retain: bool
+    """Whether the encryption key should be retained when it is removed from the Stack.
+
+    This is useful when one wants to
+    retain access to data that was encrypted with a key that is being retired.
+
+    Default:
+        true
+    """
+
 class ViaServicePrincipal(aws_cdk.aws_iam.PrincipalBase, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.ViaServicePrincipal"):
     """A principal to allow access to a key if it's being used through another AWS service."""
     def __init__(self, service_name: str, base_principal: typing.Optional[aws_cdk.aws_iam.IPrincipal]=None) -> None:
@@ -643,6 +607,6 @@ class ViaServicePrincipal(aws_cdk.aws_iam.PrincipalBase, metaclass=jsii.JSIIMeta
         return jsii.get(self, "serviceName")
 
 
-__all__ = ["CfnAlias", "CfnAliasProps", "CfnKey", "CfnKeyProps", "EncryptionKey", "EncryptionKeyAlias", "EncryptionKeyAliasProps", "EncryptionKeyImportProps", "EncryptionKeyProps", "IEncryptionKey", "ViaServicePrincipal", "__jsii_assembly__"]
+__all__ = ["CfnAlias", "CfnAliasProps", "CfnKey", "CfnKeyProps", "EncryptionKeyAlias", "EncryptionKeyAliasProps", "IKey", "Key", "KeyProps", "ViaServicePrincipal", "__jsii_assembly__"]
 
 publication.publish()
